package practice5;

import java.io.IOException;
import java.net.URL;
import java.util.ArrayList;
import java.util.List;

import javax.jdo.JDOObjectNotFoundException;
import javax.jdo.PersistenceManager;
import javax.servlet.RequestDispatcher;
import javax.servlet.ServletException;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;


import com.google.appengine.api.users.User;
import com.google.appengine.api.users.UserService;
import com.google.appengine.api.users.UserServiceFactory;
import com.google.gdata.client.authn.oauth.GoogleOAuthParameters;
import com.google.gdata.client.authn.oauth.OAuthException;
import com.google.gdata.client.authn.oauth.OAuthHmacSha1Signer;
import com.google.gdata.client.authn.oauth.OAuthSigner;
import com.google.gdata.client.calendar.CalendarService;
import com.google.gdata.data.calendar.CalendarEntry;
import com.google.gdata.data.calendar.CalendarFeed;
import com.google.gdata.util.ServiceException;

public class ReadServlet extends HttpServlet {

    public void doGet(HttpServletRequest req, HttpServletResponse resp) throws ServletException, IOException {
    	
		UserService userService = UserServiceFactory.getUserService();
		User user = userService.getCurrentUser();
		
		if (userService.isUserLoggedIn()) {
			String email = user.getEmail();
			
			PersistenceManager pm = PMF.get().getPersistenceManager();
			Token token = null;
			try {
				token = pm.getObjectById(Token.class, email);
			}
			catch(JDOObjectNotFoundException e) {
				//Forward to TokenRequestServlet
				RequestDispatcher rd = req.getRequestDispatcher("/tokenrequest");
		    	rd.forward(req, resp);
				return;
			}
			finally {
				pm.close();
			}
			
			//Get calendars
			GoogleOAuthParameters oauthParameters = new GoogleOAuthParameters();
			oauthParameters.setOAuthConsumerKey("anonymous");
			oauthParameters.setOAuthConsumerSecret("anonymous");
			oauthParameters.setOAuthToken(token.getToken());
			oauthParameters.setOAuthTokenSecret(token.getTokenSecret());
			
			OAuthSigner signer = new OAuthHmacSha1Signer();
			CalendarService service = new CalendarService("CalendarFeedDemo");
			List<CalendarEntry> result = null;
			try {
				service.setOAuthCredentials(oauthParameters, signer);
				CalendarFeed resultFeed = service.getFeed(
						new URL("https://www.google.com/calendar/feeds/default/allcalendars/full"), 
						CalendarFeed.class);

				result = new ArrayList<CalendarEntry>(resultFeed.getEntries());
				
			} 
			catch (OAuthException e) {
				e.printStackTrace();
			} 
			catch (ServiceException e) {
				e.printStackTrace();
			}

			req.setAttribute("user", user);
    		req.setAttribute("url", "/tokenrevoke");
        	req.setAttribute("calendars", result);
		}
    	else {
    		req.setAttribute("url", userService.createLoginURL("/"));
    	}
    
    	RequestDispatcher rd = req.getRequestDispatcher("/calendars.jsp");
    	rd.forward(req, resp);
    }
    
    public void doPost(HttpServletRequest req, HttpServletResponse resp) throws ServletException, IOException {
    	doGet(req, resp);
    }
}